import hotkeys from "hotkeys-js";

let activeBindings = new Set();

export function initHotkeys(options = { scope: "all", filterInputs: false }) {
	hotkeys.setScope(options.scope);
	hotkeys.filter = () => true;
	if (options.filterInputs === true) {
		hotkeys.filter = (e) => {
			const target = e.target || e.srcElement;
			const tagName = target.tagName;
			return !(target.isContentEditable || (tagName === 'INPUT' && target.type !== 'checkbox' && target.type !== 'radio') || tagName == "TEXTAREA" || tagName == "SELECT");

		}
	}
}


export function registerHotkeys(keyMap, options = {}) {
	Object.entries(keyMap).forEach(([key, handler]) => {
		registerHotkey(key, handler, options)
	});
}

export function registerHotkey(key, handler, options = {}) {
	const scope = options.scope || 'all';

	hotkeys(key, { scope, preventDefault: options.preventDefault !== false }, (event) => {
		handler(event);
	});
	activeBindings.add(key);
}

export function unregisterHotkey(key) {
	hotkeys.unbind(key);
	activeBindings.delete(key);
}

export function registerAllHotkeys() {
	activeBindings.forEach(key => {
		hotkeys.unbind(key);
	})
	activeBindings.clear();
}

export function pauseHotkeys() {
	hotkeys.pause();
}

export function resumeHotkeys() {
	hotkeys.unpause();
}

export function setHotkeyScope(scope) {
	hotkeys.setScope(scope);
}
