export const insertText = (textarea: HTMLTextAreaElement, text: string) => {
  const start = textarea.selectionStart;
  const end = textarea.selectionStart + text.length;
  textarea.setRangeText(text, start, end, "end");
};

export const insertExpandedPhrase = (textarea: HTMLTextAreaElement, expander: string, len: number, text: string): number => {
  const start = textarea.selectionStart - len;
  const end = textarea.selectionStart;
  textarea.setRangeText(text.concat(expander), start, end, "end");
  return end
};

const findIndexOfCurrentWord = (textarea: HTMLTextAreaElement) => {
  const currentValue = textarea.value;
  const cursorPos = textarea.selectionStart;

  let startIndex = cursorPos - 1;
  while (
    startIndex >= 0 &&
    /\p{Letter}|\p{Number}/u.test(currentValue[startIndex])
  ) {
    startIndex--;
  }
  return startIndex;
};

export const getCurrentWord = (textarea: HTMLTextAreaElement) => {
  const currentValue = textarea.value;
  const cursorPos = textarea.selectionStart;
  const startIndex = findIndexOfCurrentWord(textarea);
  return currentValue.substring(startIndex + 1, cursorPos);
};
